@@ -11,7 +11,8 @@ from . import config
 logger = logging.getLogger(__name__)
 
 
-def _get_addr_interface(addr: IPv4Address, ipdb=pyroute2.IPDB()):
+def _get_addr_interface(addr: IPv4Address):
+    ipdb = pyroute2.IPDB()
     for idx, addresses in ipdb.ipaddr.items():
         for ifaddr, prefix in addresses:
             if ip_address(ifaddr) == addr:
@@ -22,10 +23,19 @@ def _get_addr_interface(addr: IPv4Address, ipdb=pyroute2.IPDB()):
 def get_ebpf_program_run_args():
     args = []
 
+    wide_interface_warned = False
     interface = None
     for server_name, server in config.servers:
-        server_interface = _get_addr_interface(server.network.bind_ip)
-        assert server_interface is not None, f"Can't get interface name for {server.network.bind_ip}"
+        if str(server.network.bind_ip) == '0.0.0.0':
+            server_interface = None
+            if not wide_interface_warned:
+                logger.warning(
+                    "Wide interface is not supported yet. '0.0.0.0' will be interpreted like 'default interface'"
+                )
+                wide_interface_warned = True
+        else:
+            server_interface = _get_addr_interface(server.network.bind_ip)
+            assert server_interface is not None, f"Can't get interface name for {server.network.bind_ip}"
 
         if interface is None:
             interface = server_interface
@@ -35,9 +45,11 @@ def get_ebpf_program_run_args():
                 'Different interfaces dont supported yet: ' f'{server_interface} != {interface}'
             )
 
-        args += ['-p', f'{server.network.server_port}:{server.network.bind_port}']
+        if not server.network.ebpf_no_redirect:
+            args += ['-p', f'{server.network.server_port}:{server.network.bind_port}']
 
-    args += ['-i', interface]
+    if interface is not None:
+        args += ['-i', interface]
 
     return args
 
